@@ -17,7 +17,13 @@ function squirrelmail_plugin_init_vlogin() {
   global $squirrelmail_plugin_hooks;
 
 
-  $squirrelmail_plugin_hooks['login_before']['vlogin'] = 'vlogin_domain';
+  $squirrelmail_plugin_hooks['login_before']['vlogin']               = 'vlogin_domain';
+
+  $squirrelmail_plugin_hooks['optpage_loadhook_display']['vlogin']   = 'vlogin_display_options';
+  $squirrelmail_plugin_hooks['optpage_loadhook_personal']['vlogin']  = 'vlogin_display_options';
+  $squirrelmail_plugin_hooks['optpage_loadhook_folder']['vlogin']    = 'vlogin_display_options';
+  $squirrelmail_plugin_hooks['optpage_loadhook_highlight']['vlogin'] = 'vlogin_display_options';
+  $squirrelmail_plugin_hooks['optpage_loadhook_order']['vlogin']     = 'vlogin_display_options';
 
 
   // yes, this is all necessary, in order to offer 
@@ -64,6 +70,15 @@ function vlogin_domain()
 }
 
 
+function vlogin_display_options() 
+{
+
+   include_once(SM_PATH . 'plugins/vlogin/functions.php');
+   vlogin_display_options_do();
+
+}
+
+
 function vlogin_overrideSmConfig() 
 {
 
@@ -73,9 +88,10 @@ function vlogin_overrideSmConfig()
 }
 
 
-function vlogin_version() {
+function vlogin_version() 
+{
 
-   return '3.4';
+   return '3.4.1';
 
 }
 
